;; This is an operating system configuration template
;; for a "desktop" setup with X11.

(use-modules (gnu) (gnu system nss))
(use-service-modules desktop)
(use-package-modules xfce ratpoison certs)

(operating-system
  (host-name "garuda")
  (timezone "America/Los_Angeles")
  (locale "en_US.UTF-8")

  (mapped-devices (list (mapped-device
                         (source "/dev/sda2")
                         (target "home")
                         (type luks-device-mapping))))

  ;; Assuming /dev/sdX is the target hard disk, and "root"
  ;; is the label of the target root file system.
  (bootloader (grub-configuration (device "/dev/sda")))
  (file-systems (cons* (file-system
                        (device "root")
                        (title 'label)
                        (mount-point "/")
                        (type "ext4"))
                       (file-system
                        (device "/dev/mapper/home")
                        (mount-point "/home")
                        (type "ext4"))
                      %base-file-systems))

  (users (cons (user-account
                (name "marusich")
                (comment "Chris Marusich")
                (group "users")
                (supplementary-groups '("wheel" "netdev"
                                        "audio" "video"))
                (home-directory "/home/marusich"))
               %base-user-accounts))

  ;; Add Xfce and Ratpoison; that allows us to choose
  ;; sessions using either of these at the log-in screen.
  (packages (cons* xfce ratpoison    ;desktop environments
                   nss-certs         ;for HTTPS access
                   %base-packages))

  ;; Use the "desktop" services, which include the X11
  ;; log-in service, networking with Wicd, and more.
  (services %desktop-services)

  ;; Allow resolution of '.local' host names with mDNS.
  (name-service-switch %mdns-host-lookup-nss))
